"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from cryptoapis.api_client import ApiClient, Endpoint as _Endpoint
from cryptoapis.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from cryptoapis.model.get_address_details402_response import GetAddressDetails402Response
from cryptoapis.model.get_address_details409_response import GetAddressDetails409Response
from cryptoapis.model.get_address_details415_response import GetAddressDetails415Response
from cryptoapis.model.get_address_details422_response import GetAddressDetails422Response
from cryptoapis.model.get_address_details429_response import GetAddressDetails429Response
from cryptoapis.model.get_address_details500_response import GetAddressDetails500Response
from cryptoapis.model.get_address_details_from_callback400_response import GetAddressDetailsFromCallback400Response
from cryptoapis.model.get_address_details_from_callback401_response import GetAddressDetailsFromCallback401Response
from cryptoapis.model.get_address_details_from_callback403_response import GetAddressDetailsFromCallback403Response
from cryptoapis.model.get_address_details_from_callback404_response import GetAddressDetailsFromCallback404Response
from cryptoapis.model.get_address_details_from_callback_r import GetAddressDetailsFromCallbackR
from cryptoapis.model.get_block_details_by_block_hash_from_callback400_response import GetBlockDetailsByBlockHashFromCallback400Response
from cryptoapis.model.get_block_details_by_block_hash_from_callback401_response import GetBlockDetailsByBlockHashFromCallback401Response
from cryptoapis.model.get_block_details_by_block_hash_from_callback403_response import GetBlockDetailsByBlockHashFromCallback403Response
from cryptoapis.model.get_block_details_by_block_hash_from_callback_r import GetBlockDetailsByBlockHashFromCallbackR
from cryptoapis.model.get_block_details_by_block_height_from_callback400_response import GetBlockDetailsByBlockHeightFromCallback400Response
from cryptoapis.model.get_block_details_by_block_height_from_callback401_response import GetBlockDetailsByBlockHeightFromCallback401Response
from cryptoapis.model.get_block_details_by_block_height_from_callback403_response import GetBlockDetailsByBlockHeightFromCallback403Response
from cryptoapis.model.get_block_details_by_block_height_from_callback_r import GetBlockDetailsByBlockHeightFromCallbackR
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback400_response import GetTransactionDetailsByTransactionIDFromCallback400Response
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback401_response import GetTransactionDetailsByTransactionIDFromCallback401Response
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback403_response import GetTransactionDetailsByTransactionIDFromCallback403Response
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_r import GetTransactionDetailsByTransactionIDFromCallbackR
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_id404_response import GetXRPRippleTransactionDetailsByTransactionID404Response
from cryptoapis.model.list_transactions_by_block_height404_response import ListTransactionsByBlockHeight404Response


class CallbackDataApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_address_details_from_callback_endpoint = _Endpoint(
            settings={
                'response_type': (GetAddressDetailsFromCallbackR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-events/{blockchain}/{network}/addresses/{address}',
                'operation_id': 'get_address_details_from_callback',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'blockchain',
                    'network',
                    'address',
                    'context',
                ],
                'required': [
                    'blockchain',
                    'network',
                    'address',
                ],
                'nullable': [
                ],
                'enum': [
                    'blockchain',
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('blockchain',): {

                        "BITCOIN": "bitcoin",
                        "BITCOIN-CASH": "bitcoin-cash",
                        "LITECOIN": "litecoin",
                        "DASH": "dash",
                        "DOGECOIN": "dogecoin",
                        "ETHEREUM": "ethereum",
                        "ETHEREUM-CLASSIC": "ethereum-classic",
                        "BINANCE-SMART-CHAIN": "binance-smart-chain",
                        "XRP": "xrp",
                        "ZILLIQA": "zilliqa",
                        "ZCASH": "zcash"
                    },
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet",
                        "ROPSTEN": "ropsten",
                        "MORDOR": "mordor"
                    },
                },
                'openapi_types': {
                    'blockchain':
                        (str,),
                    'network':
                        (str,),
                    'address':
                        (str,),
                    'context':
                        (str,),
                },
                'attribute_map': {
                    'blockchain': 'blockchain',
                    'network': 'network',
                    'address': 'address',
                    'context': 'context',
                },
                'location_map': {
                    'blockchain': 'path',
                    'network': 'path',
                    'address': 'path',
                    'context': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_block_details_by_block_hash_from_callback_endpoint = _Endpoint(
            settings={
                'response_type': (GetBlockDetailsByBlockHashFromCallbackR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-events/{blockchain}/{network}/blocks/hash/{blockHash}',
                'operation_id': 'get_block_details_by_block_hash_from_callback',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'blockchain',
                    'network',
                    'block_hash',
                    'context',
                ],
                'required': [
                    'blockchain',
                    'network',
                    'block_hash',
                ],
                'nullable': [
                ],
                'enum': [
                    'blockchain',
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('blockchain',): {

                        "BITCOIN": "bitcoin",
                        "BITCOIN-CASH": "bitcoin-cash",
                        "LITECOIN": "litecoin",
                        "DASH": "dash",
                        "DOGECOIN": "dogecoin",
                        "ETHEREUM": "ethereum",
                        "BINANCE-SMART-CHAIN": "binance-smart-chain",
                        "ETHEREUM-CLASSIC": "ethereum-classic",
                        "ZILLIQA": "zilliqa",
                        "XRP": "xrp",
                        "ZCASH": "zcash"
                    },
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet",
                        "ROPSTEN": "ropsten",
                        "MORDOR": "mordor"
                    },
                },
                'openapi_types': {
                    'blockchain':
                        (str,),
                    'network':
                        (str,),
                    'block_hash':
                        (str,),
                    'context':
                        (str,),
                },
                'attribute_map': {
                    'blockchain': 'blockchain',
                    'network': 'network',
                    'block_hash': 'blockHash',
                    'context': 'context',
                },
                'location_map': {
                    'blockchain': 'path',
                    'network': 'path',
                    'block_hash': 'path',
                    'context': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_block_details_by_block_height_from_callback_endpoint = _Endpoint(
            settings={
                'response_type': (GetBlockDetailsByBlockHeightFromCallbackR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-events/{blockchain}/{network}/blocks/height/{blockHeight}',
                'operation_id': 'get_block_details_by_block_height_from_callback',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'blockchain',
                    'network',
                    'block_height',
                    'context',
                ],
                'required': [
                    'blockchain',
                    'network',
                    'block_height',
                ],
                'nullable': [
                ],
                'enum': [
                    'blockchain',
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('blockchain',): {

                        "BITCOIN": "bitcoin",
                        "BITCOIN-CASH": "bitcoin-cash",
                        "LITECOIN": "litecoin",
                        "DASH": "dash",
                        "DOGECOIN": "dogecoin",
                        "ETHEREUM": "ethereum",
                        "BINANCE-SMART-CHAIN": "binance-smart-chain",
                        "ETHEREUM-CLASSIC": "ethereum-classic",
                        "ZILLIQA": "zilliqa",
                        "XRP": "xrp",
                        "ZCASH": "zcash"
                    },
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet",
                        "ROPSTEN": "ropsten",
                        "MORDOR": "mordor"
                    },
                },
                'openapi_types': {
                    'blockchain':
                        (str,),
                    'network':
                        (str,),
                    'block_height':
                        (str,),
                    'context':
                        (str,),
                },
                'attribute_map': {
                    'blockchain': 'blockchain',
                    'network': 'network',
                    'block_height': 'blockHeight',
                    'context': 'context',
                },
                'location_map': {
                    'blockchain': 'path',
                    'network': 'path',
                    'block_height': 'path',
                    'context': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_transaction_details_by_transaction_id_from_callback_endpoint = _Endpoint(
            settings={
                'response_type': (GetTransactionDetailsByTransactionIDFromCallbackR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-events/{blockchain}/{network}/transactions/{transactionId}',
                'operation_id': 'get_transaction_details_by_transaction_id_from_callback',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'blockchain',
                    'network',
                    'transaction_id',
                    'context',
                ],
                'required': [
                    'blockchain',
                    'network',
                    'transaction_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'blockchain',
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('blockchain',): {

                        "BITCOIN": "bitcoin",
                        "ETHEREUM": "ethereum",
                        "BITCOIN-CASH": "bitcoin-cash",
                        "LITECOIN": "litecoin",
                        "DASH": "dash",
                        "DOGECOIN": "dogecoin",
                        "ZCASH": "zcash",
                        "ETHEREUM-CLASSIC": "ethereum-classic",
                        "BINANCE-SMART-CHAIN": "binance-smart-chain",
                        "ZILLIQA": "zilliqa",
                        "XRP": "xrp"
                    },
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet",
                        "ROPSTEN": "ropsten",
                        "MORDOR": "mordor"
                    },
                },
                'openapi_types': {
                    'blockchain':
                        (str,),
                    'network':
                        (str,),
                    'transaction_id':
                        (str,),
                    'context':
                        (str,),
                },
                'attribute_map': {
                    'blockchain': 'blockchain',
                    'network': 'network',
                    'transaction_id': 'transactionId',
                    'context': 'context',
                },
                'location_map': {
                    'blockchain': 'path',
                    'network': 'path',
                    'transaction_id': 'path',
                    'context': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def get_address_details_from_callback(
        self,
        blockchain,
        network,
        address,
        **kwargs
    ):
        """Get Address Details From Callback  # noqa: E501

        This endpoint creates a shortcut to obtain information from Blockchain data by going through Blockchain Events and a specific Event Subscription. It provides data for a specific address from the Event it takes part in only if the address already exists in the blockchain events subscriptions. It applies only for Events related to that customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_address_details_from_callback(blockchain, network, address, async_req=True)
        >>> result = thread.get()

        Args:
            blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.
            network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\" are test networks.
            address (str): Represents the public address, which is a compressed and shortened form of a public key.

        Keyword Args:
            context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GetAddressDetailsFromCallbackR
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['blockchain'] = \
            blockchain
        kwargs['network'] = \
            network
        kwargs['address'] = \
            address
        return self.get_address_details_from_callback_endpoint.call_with_http_info(**kwargs)

    def get_block_details_by_block_hash_from_callback(
        self,
        blockchain,
        network,
        block_hash,
        **kwargs
    ):
        """Get Block Details By Block Hash From Callback  # noqa: E501

        This endpoint creates a shortcut to obtain information from Blockchain data by going through Blockchain Events and a specific Event Subscription. It provides data for a specific block by providing the `blockHash` attribute from the Event it takes part in and after making check that the customer in question does have a subscription for this block. It applies only for Events related to that user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_block_details_by_block_hash_from_callback(blockchain, network, block_hash, async_req=True)
        >>> result = thread.get()

        Args:
            blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.
            network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\" are test networks.
            block_hash (str): Represents the hash of the block, which is its unique identifier. It represents a cryptographic digital fingerprint made by hashing the block header twice through the SHA256 algorithm.

        Keyword Args:
            context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GetBlockDetailsByBlockHashFromCallbackR
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['blockchain'] = \
            blockchain
        kwargs['network'] = \
            network
        kwargs['block_hash'] = \
            block_hash
        return self.get_block_details_by_block_hash_from_callback_endpoint.call_with_http_info(**kwargs)

    def get_block_details_by_block_height_from_callback(
        self,
        blockchain,
        network,
        block_height,
        **kwargs
    ):
        """Get Block Details By Block Height From Callback  # noqa: E501

        This endpoint creates a shortcut to obtain information from Blockchain data by going through Blockchain Events and a specific Event Subscription. It provides data for the specific Block by providing the `blockHeight` attribute from the Event it takes part in. It applies only for Events related to that user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_block_details_by_block_height_from_callback(blockchain, network, block_height, async_req=True)
        >>> result = thread.get()

        Args:
            blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.
            network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\" are test networks.
            block_height (str): Numeric representation of the block height

        Keyword Args:
            context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GetBlockDetailsByBlockHeightFromCallbackR
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['blockchain'] = \
            blockchain
        kwargs['network'] = \
            network
        kwargs['block_height'] = \
            block_height
        return self.get_block_details_by_block_height_from_callback_endpoint.call_with_http_info(**kwargs)

    def get_transaction_details_by_transaction_id_from_callback(
        self,
        blockchain,
        network,
        transaction_id,
        **kwargs
    ):
        """Get Transaction Details By Transaction ID From Callback  # noqa: E501

        This endpoint creates a shortcut to obtain information from Blockchain data by going through Blockchain Events and a specific Event Subscription. It provides data for a specific transaction from the Event it takes part in by providing the `transactionId` attribute. It applies only for Events related to that user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_transaction_details_by_transaction_id_from_callback(blockchain, network, transaction_id, async_req=True)
        >>> result = thread.get()

        Args:
            blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.
            network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\" are test networks.
            transaction_id (str): String identifier of the transaction

        Keyword Args:
            context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GetTransactionDetailsByTransactionIDFromCallbackR
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['blockchain'] = \
            blockchain
        kwargs['network'] = \
            network
        kwargs['transaction_id'] = \
            transaction_id
        return self.get_transaction_details_by_transaction_id_from_callback_endpoint.call_with_http_info(**kwargs)




"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.create_automatic_coins_forwarding_e403 import CreateAutomaticCoinsForwardingE403
globals()['CreateAutomaticCoinsForwardingE403'] = CreateAutomaticCoinsForwardingE403
from cryptoapis.model.create_automatic_coins_forwarding403_response import CreateAutomaticCoinsForwarding403Response


class TestCreateAutomaticCoinsForwarding403Response(unittest.TestCase):
    """CreateAutomaticCoinsForwarding403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateAutomaticCoinsForwarding403Response(self):
        """Test CreateAutomaticCoinsForwarding403Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateAutomaticCoinsForwarding403Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.banned_ip_address_details_inner import BannedIpAddressDetailsInner
from cryptoapis.model.invalid_data import InvalidData
from cryptoapis.model.wallet_as_a_service_address_balance_not_enough import WalletAsAServiceAddressBalanceNotEnough
from cryptoapis.model.wallet_as_a_service_wallet_balance_not_enough import WalletAsAServiceWalletBalanceNotEnough
globals()['BannedIpAddressDetailsInner'] = BannedIpAddressDetailsInner
globals()['InvalidData'] = InvalidData
globals()['WalletAsAServiceAddressBalanceNotEnough'] = WalletAsAServiceAddressBalanceNotEnough
globals()['WalletAsAServiceWalletBalanceNotEnough'] = WalletAsAServiceWalletBalanceNotEnough
from cryptoapis.model.create_coins_transaction_request_from_address_e409 import CreateCoinsTransactionRequestFromAddressE409


class TestCreateCoinsTransactionRequestFromAddressE409(unittest.TestCase):
    """CreateCoinsTransactionRequestFromAddressE409 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateCoinsTransactionRequestFromAddressE409(self):
        """Test CreateCoinsTransactionRequestFromAddressE409"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateCoinsTransactionRequestFromAddressE409()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_asset_details_by_asset_idri_asset_logo import GetAssetDetailsByAssetIDRIAssetLogo
from cryptoapis.model.get_asset_details_by_asset_idri_latest_rate import GetAssetDetailsByAssetIDRILatestRate
from cryptoapis.model.get_asset_details_by_asset_idris import GetAssetDetailsByAssetIDRIS
globals()['GetAssetDetailsByAssetIDRIAssetLogo'] = GetAssetDetailsByAssetIDRIAssetLogo
globals()['GetAssetDetailsByAssetIDRILatestRate'] = GetAssetDetailsByAssetIDRILatestRate
globals()['GetAssetDetailsByAssetIDRIS'] = GetAssetDetailsByAssetIDRIS
from cryptoapis.model.get_asset_details_by_asset_idri import GetAssetDetailsByAssetIDRI


class TestGetAssetDetailsByAssetIDRI(unittest.TestCase):
    """GetAssetDetailsByAssetIDRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetAssetDetailsByAssetIDRI(self):
        """Test GetAssetDetailsByAssetIDRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetAssetDetailsByAssetIDRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.address_tokens_transaction_confirmed_bep20 import AddressTokensTransactionConfirmedBep20
from cryptoapis.model.address_tokens_transaction_confirmed_erc20 import AddressTokensTransactionConfirmedErc20
from cryptoapis.model.address_tokens_transaction_confirmed_erc721 import AddressTokensTransactionConfirmedErc721
from cryptoapis.model.address_tokens_transaction_confirmed_omni import AddressTokensTransactionConfirmedOmni
globals()['AddressTokensTransactionConfirmedBep20'] = AddressTokensTransactionConfirmedBep20
globals()['AddressTokensTransactionConfirmedErc20'] = AddressTokensTransactionConfirmedErc20
globals()['AddressTokensTransactionConfirmedErc721'] = AddressTokensTransactionConfirmedErc721
globals()['AddressTokensTransactionConfirmedOmni'] = AddressTokensTransactionConfirmedOmni
from cryptoapis.model.address_tokens_transaction_confirmed_token import AddressTokensTransactionConfirmedToken


class TestAddressTokensTransactionConfirmedToken(unittest.TestCase):
    """AddressTokensTransactionConfirmedToken unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAddressTokensTransactionConfirmedToken(self):
        """Test AddressTokensTransactionConfirmedToken"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AddressTokensTransactionConfirmedToken()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_ide400 import GetXRPRippleTransactionDetailsByTransactionIDE400
globals()['GetXRPRippleTransactionDetailsByTransactionIDE400'] = GetXRPRippleTransactionDetailsByTransactionIDE400
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_id400_response import GetXRPRippleTransactionDetailsByTransactionID400Response


class TestGetXRPRippleTransactionDetailsByTransactionID400Response(unittest.TestCase):
    """GetXRPRippleTransactionDetailsByTransactionID400Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetXRPRippleTransactionDetailsByTransactionID400Response(self):
        """Test GetXRPRippleTransactionDetailsByTransactionID400Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetXRPRippleTransactionDetailsByTransactionID400Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_internal_transaction_details_by_transaction_hash_r_data import ListInternalTransactionDetailsByTransactionHashRData
globals()['ListInternalTransactionDetailsByTransactionHashRData'] = ListInternalTransactionDetailsByTransactionHashRData
from cryptoapis.model.list_internal_transaction_details_by_transaction_hash_r import ListInternalTransactionDetailsByTransactionHashR


class TestListInternalTransactionDetailsByTransactionHashR(unittest.TestCase):
    """ListInternalTransactionDetailsByTransactionHashR unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListInternalTransactionDetailsByTransactionHashR(self):
        """Test ListInternalTransactionDetailsByTransactionHashR"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListInternalTransactionDetailsByTransactionHashR()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_latest_mined_blocks_ribsb import ListLatestMinedBlocksRIBSB
from cryptoapis.model.list_latest_mined_blocks_ribsbc import ListLatestMinedBlocksRIBSBC
from cryptoapis.model.list_latest_mined_blocks_ribsbsc import ListLatestMinedBlocksRIBSBSC
from cryptoapis.model.list_latest_mined_blocks_ribsd import ListLatestMinedBlocksRIBSD
from cryptoapis.model.list_latest_mined_blocks_ribsd2 import ListLatestMinedBlocksRIBSD2
from cryptoapis.model.list_latest_mined_blocks_ribse import ListLatestMinedBlocksRIBSE
from cryptoapis.model.list_latest_mined_blocks_ribsec import ListLatestMinedBlocksRIBSEC
from cryptoapis.model.list_latest_mined_blocks_ribsl import ListLatestMinedBlocksRIBSL
from cryptoapis.model.list_latest_mined_blocks_ribsz import ListLatestMinedBlocksRIBSZ
from cryptoapis.model.list_latest_mined_blocks_ribsz2 import ListLatestMinedBlocksRIBSZ2
globals()['ListLatestMinedBlocksRIBSB'] = ListLatestMinedBlocksRIBSB
globals()['ListLatestMinedBlocksRIBSBC'] = ListLatestMinedBlocksRIBSBC
globals()['ListLatestMinedBlocksRIBSBSC'] = ListLatestMinedBlocksRIBSBSC
globals()['ListLatestMinedBlocksRIBSD'] = ListLatestMinedBlocksRIBSD
globals()['ListLatestMinedBlocksRIBSD2'] = ListLatestMinedBlocksRIBSD2
globals()['ListLatestMinedBlocksRIBSE'] = ListLatestMinedBlocksRIBSE
globals()['ListLatestMinedBlocksRIBSEC'] = ListLatestMinedBlocksRIBSEC
globals()['ListLatestMinedBlocksRIBSL'] = ListLatestMinedBlocksRIBSL
globals()['ListLatestMinedBlocksRIBSZ'] = ListLatestMinedBlocksRIBSZ
globals()['ListLatestMinedBlocksRIBSZ2'] = ListLatestMinedBlocksRIBSZ2
from cryptoapis.model.list_latest_mined_blocks_ribs import ListLatestMinedBlocksRIBS


class TestListLatestMinedBlocksRIBS(unittest.TestCase):
    """ListLatestMinedBlocksRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListLatestMinedBlocksRIBS(self):
        """Test ListLatestMinedBlocksRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListLatestMinedBlocksRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vout_inner import GetTransactionDetailsByTransactionIDRIBSZVoutInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_output_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribsb import ListConfirmedTransactionsByAddressAndTimeRangeRIBSB
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribsbc import ListConfirmedTransactionsByAddressAndTimeRangeRIBSBC
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribsbsc import ListConfirmedTransactionsByAddressAndTimeRangeRIBSBSC
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribsd import ListConfirmedTransactionsByAddressAndTimeRangeRIBSD
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribsd2 import ListConfirmedTransactionsByAddressAndTimeRangeRIBSD2
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribse import ListConfirmedTransactionsByAddressAndTimeRangeRIBSE
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribsec import ListConfirmedTransactionsByAddressAndTimeRangeRIBSEC
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribsl import ListConfirmedTransactionsByAddressAndTimeRangeRIBSL
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribsz import ListConfirmedTransactionsByAddressAndTimeRangeRIBSZ
from cryptoapis.model.list_confirmed_transactions_by_address_ribsbsc_gas_price import ListConfirmedTransactionsByAddressRIBSBSCGasPrice
from cryptoapis.model.list_confirmed_transactions_by_address_ribsz_vin_inner import ListConfirmedTransactionsByAddressRIBSZVinInner
from cryptoapis.model.list_confirmed_transactions_by_address_ribszv_join_split_inner import ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVoutInner'] = GetTransactionDetailsByTransactionIDRIBSZVoutInner
globals()['ListConfirmedTransactionsByAddressAndTimeRangeRIBSB'] = ListConfirmedTransactionsByAddressAndTimeRangeRIBSB
globals()['ListConfirmedTransactionsByAddressAndTimeRangeRIBSBC'] = ListConfirmedTransactionsByAddressAndTimeRangeRIBSBC
globals()['ListConfirmedTransactionsByAddressAndTimeRangeRIBSBSC'] = ListConfirmedTransactionsByAddressAndTimeRangeRIBSBSC
globals()['ListConfirmedTransactionsByAddressAndTimeRangeRIBSD'] = ListConfirmedTransactionsByAddressAndTimeRangeRIBSD
globals()['ListConfirmedTransactionsByAddressAndTimeRangeRIBSD2'] = ListConfirmedTransactionsByAddressAndTimeRangeRIBSD2
globals()['ListConfirmedTransactionsByAddressAndTimeRangeRIBSE'] = ListConfirmedTransactionsByAddressAndTimeRangeRIBSE
globals()['ListConfirmedTransactionsByAddressAndTimeRangeRIBSEC'] = ListConfirmedTransactionsByAddressAndTimeRangeRIBSEC
globals()['ListConfirmedTransactionsByAddressAndTimeRangeRIBSL'] = ListConfirmedTransactionsByAddressAndTimeRangeRIBSL
globals()['ListConfirmedTransactionsByAddressAndTimeRangeRIBSZ'] = ListConfirmedTransactionsByAddressAndTimeRangeRIBSZ
globals()['ListConfirmedTransactionsByAddressRIBSBSCGasPrice'] = ListConfirmedTransactionsByAddressRIBSBSCGasPrice
globals()['ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner'] = ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner
globals()['ListConfirmedTransactionsByAddressRIBSZVinInner'] = ListConfirmedTransactionsByAddressRIBSZVinInner
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribs import ListConfirmedTransactionsByAddressAndTimeRangeRIBS


class TestListConfirmedTransactionsByAddressAndTimeRangeRIBS(unittest.TestCase):
    """ListConfirmedTransactionsByAddressAndTimeRangeRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListConfirmedTransactionsByAddressAndTimeRangeRIBS(self):
        """Test ListConfirmedTransactionsByAddressAndTimeRangeRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListConfirmedTransactionsByAddressAndTimeRangeRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_hd_wallet_x_pub_y_pub_z_pub_transactions_e400 import ListHDWalletXPubYPubZPubTransactionsE400
globals()['ListHDWalletXPubYPubZPubTransactionsE400'] = ListHDWalletXPubYPubZPubTransactionsE400
from cryptoapis.model.list_hd_wallet_x_pub_y_pub_z_pub_transactions400_response import ListHDWalletXPubYPubZPubTransactions400Response


class TestListHDWalletXPubYPubZPubTransactions400Response(unittest.TestCase):
    """ListHDWalletXPubYPubZPubTransactions400Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListHDWalletXPubYPubZPubTransactions400Response(self):
        """Test ListHDWalletXPubYPubZPubTransactions400Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListHDWalletXPubYPubZPubTransactions400Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_zilliqa_address_details_e403 import GetZilliqaAddressDetailsE403
globals()['GetZilliqaAddressDetailsE403'] = GetZilliqaAddressDetailsE403
from cryptoapis.model.get_zilliqa_address_details403_response import GetZilliqaAddressDetails403Response


class TestGetZilliqaAddressDetails403Response(unittest.TestCase):
    """GetZilliqaAddressDetails403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetZilliqaAddressDetails403Response(self):
        """Test GetZilliqaAddressDetails403Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetZilliqaAddressDetails403Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
from cryptoapis.model.list_transactions_by_block_height_ribsz_vin_inner import ListTransactionsByBlockHeightRIBSZVinInner
from cryptoapis.model.list_transactions_by_block_height_ribsz_vout_inner import ListTransactionsByBlockHeightRIBSZVoutInner
from cryptoapis.model.list_transactions_by_block_height_ribszv_join_split_inner import ListTransactionsByBlockHeightRIBSZVJoinSplitInner
from cryptoapis.model.list_transactions_by_block_height_ribszv_shielded_output_inner import ListTransactionsByBlockHeightRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['ListTransactionsByBlockHeightRIBSZVJoinSplitInner'] = ListTransactionsByBlockHeightRIBSZVJoinSplitInner
globals()['ListTransactionsByBlockHeightRIBSZVShieldedOutputInner'] = ListTransactionsByBlockHeightRIBSZVShieldedOutputInner
globals()['ListTransactionsByBlockHeightRIBSZVinInner'] = ListTransactionsByBlockHeightRIBSZVinInner
globals()['ListTransactionsByBlockHeightRIBSZVoutInner'] = ListTransactionsByBlockHeightRIBSZVoutInner
from cryptoapis.model.list_transactions_by_block_height_ribsz import ListTransactionsByBlockHeightRIBSZ


class TestListTransactionsByBlockHeightRIBSZ(unittest.TestCase):
    """ListTransactionsByBlockHeightRIBSZ unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListTransactionsByBlockHeightRIBSZ(self):
        """Test ListTransactionsByBlockHeightRIBSZ"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListTransactionsByBlockHeightRIBSZ()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_all_assets_from_all_wallets_e403 import ListAllAssetsFromAllWalletsE403
globals()['ListAllAssetsFromAllWalletsE403'] = ListAllAssetsFromAllWalletsE403
from cryptoapis.model.list_all_assets_from_all_wallets403_response import ListAllAssetsFromAllWallets403Response


class TestListAllAssetsFromAllWallets403Response(unittest.TestCase):
    """ListAllAssetsFromAllWallets403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListAllAssetsFromAllWallets403Response(self):
        """Test ListAllAssetsFromAllWallets403Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListAllAssetsFromAllWallets403Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from cryptoapis.api_client import ApiClient, Endpoint as _Endpoint
from cryptoapis.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from cryptoapis.model.activate_blockchain_event_subscription400_response import ActivateBlockchainEventSubscription400Response
from cryptoapis.model.activate_blockchain_event_subscription401_response import ActivateBlockchainEventSubscription401Response
from cryptoapis.model.activate_blockchain_event_subscription403_response import ActivateBlockchainEventSubscription403Response
from cryptoapis.model.activate_blockchain_event_subscription_r import ActivateBlockchainEventSubscriptionR
from cryptoapis.model.activate_blockchain_event_subscription_rb import ActivateBlockchainEventSubscriptionRB
from cryptoapis.model.delete_blockchain_event_subscription400_response import DeleteBlockchainEventSubscription400Response
from cryptoapis.model.delete_blockchain_event_subscription401_response import DeleteBlockchainEventSubscription401Response
from cryptoapis.model.delete_blockchain_event_subscription403_response import DeleteBlockchainEventSubscription403Response
from cryptoapis.model.delete_blockchain_event_subscription_r import DeleteBlockchainEventSubscriptionR
from cryptoapis.model.get_address_details402_response import GetAddressDetails402Response
from cryptoapis.model.get_address_details409_response import GetAddressDetails409Response
from cryptoapis.model.get_address_details415_response import GetAddressDetails415Response
from cryptoapis.model.get_address_details422_response import GetAddressDetails422Response
from cryptoapis.model.get_address_details429_response import GetAddressDetails429Response
from cryptoapis.model.get_address_details500_response import GetAddressDetails500Response
from cryptoapis.model.get_blockchain_event_subscription_details_by_reference_id400_response import GetBlockchainEventSubscriptionDetailsByReferenceID400Response
from cryptoapis.model.get_blockchain_event_subscription_details_by_reference_id401_response import GetBlockchainEventSubscriptionDetailsByReferenceID401Response
from cryptoapis.model.get_blockchain_event_subscription_details_by_reference_id403_response import GetBlockchainEventSubscriptionDetailsByReferenceID403Response
from cryptoapis.model.get_blockchain_event_subscription_details_by_reference_idr import GetBlockchainEventSubscriptionDetailsByReferenceIDR
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_id404_response import GetXRPRippleTransactionDetailsByTransactionID404Response
from cryptoapis.model.list_blockchain_events_subscriptions400_response import ListBlockchainEventsSubscriptions400Response
from cryptoapis.model.list_blockchain_events_subscriptions401_response import ListBlockchainEventsSubscriptions401Response
from cryptoapis.model.list_blockchain_events_subscriptions403_response import ListBlockchainEventsSubscriptions403Response
from cryptoapis.model.list_blockchain_events_subscriptions_r import ListBlockchainEventsSubscriptionsR


class ManageSubscriptionsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.activate_blockchain_event_subscription_endpoint = _Endpoint(
            settings={
                'response_type': (ActivateBlockchainEventSubscriptionR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-events/subscriptions/{referenceId}/activate',
                'operation_id': 'activate_blockchain_event_subscription',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'reference_id',
                    'context',
                    'activate_blockchain_event_subscription_rb',
                ],
                'required': [
                    'reference_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'reference_id':
                        (str,),
                    'context':
                        (str,),
                    'activate_blockchain_event_subscription_rb':
                        (ActivateBlockchainEventSubscriptionRB,),
                },
                'attribute_map': {
                    'reference_id': 'referenceId',
                    'context': 'context',
                },
                'location_map': {
                    'reference_id': 'path',
                    'context': 'query',
                    'activate_blockchain_event_subscription_rb': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.delete_blockchain_event_subscription_endpoint = _Endpoint(
            settings={
                'response_type': (DeleteBlockchainEventSubscriptionR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-events/{blockchain}/{network}/subscriptions/{referenceId}',
                'operation_id': 'delete_blockchain_event_subscription',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'blockchain',
                    'network',
                    'reference_id',
                    'context',
                ],
                'required': [
                    'blockchain',
                    'network',
                    'reference_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'blockchain',
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('blockchain',): {

                        "BITCOIN": "bitcoin",
                        "BITCOIN-CASH": "bitcoin-cash",
                        "LITECOIN": "litecoin",
                        "DOGECOIN": "dogecoin",
                        "DASH": "dash",
                        "ETHEREUM": "ethereum",
                        "ETHEREUM-CLASSIC": "ethereum-classic",
                        "XRP": "xrp",
                        "ZILLIQA": "zilliqa",
                        "BINANCE-SMART-CHAIN": "binance-smart-chain",
                        "ZCASH": "zcash"
                    },
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet",
                        "ROPSTEN": "ropsten",
                        "MORDOR": "mordor"
                    },
                },
                'openapi_types': {
                    'blockchain':
                        (str,),
                    'network':
                        (str,),
                    'reference_id':
                        (str,),
                    'context':
                        (str,),
                },
                'attribute_map': {
                    'blockchain': 'blockchain',
                    'network': 'network',
                    'reference_id': 'referenceId',
                    'context': 'context',
                },
                'location_map': {
                    'blockchain': 'path',
                    'network': 'path',
                    'reference_id': 'path',
                    'context': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_blockchain_event_subscription_details_by_reference_id_endpoint = _Endpoint(
            settings={
                'response_type': (GetBlockchainEventSubscriptionDetailsByReferenceIDR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-events/subscriptions/{referenceId}',
                'operation_id': 'get_blockchain_event_subscription_details_by_reference_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'reference_id',
                    'context',
                ],
                'required': [
                    'reference_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'reference_id':
                        (str,),
                    'context':
                        (str,),
                },
                'attribute_map': {
                    'reference_id': 'referenceId',
                    'context': 'context',
                },
                'location_map': {
                    'reference_id': 'path',
                    'context': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_blockchain_events_subscriptions_endpoint = _Endpoint(
            settings={
                'response_type': (ListBlockchainEventsSubscriptionsR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/blockchain-events/{blockchain}/{network}/subscriptions',
                'operation_id': 'list_blockchain_events_subscriptions',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'blockchain',
                    'network',
                    'context',
                    'limit',
                    'offset',
                ],
                'required': [
                    'blockchain',
                    'network',
                ],
                'nullable': [
                ],
                'enum': [
                    'blockchain',
                    'network',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('blockchain',): {

                        "BITCOIN": "bitcoin",
                        "BITCOIN-CASH": "bitcoin-cash",
                        "LITECOIN": "litecoin",
                        "DOGECOIN": "dogecoin",
                        "DASH": "dash",
                        "ETHEREUM": "ethereum",
                        "ETHEREUM-CLASSIC": "ethereum-classic",
                        "XRP": "xrp",
                        "ZILLIQA": "zilliqa",
                        "BINANCE-SMART-CHAIN": "binance-smart-chain",
                        "ZCASH": "zcash"
                    },
                    ('network',): {

                        "MAINNET": "mainnet",
                        "TESTNET": "testnet",
                        "ROPSTEN": "ropsten",
                        "MORDOR": "mordor"
                    },
                },
                'openapi_types': {
                    'blockchain':
                        (str,),
                    'network':
                        (str,),
                    'context':
                        (str,),
                    'limit':
                        (int,),
                    'offset':
                        (int,),
                },
                'attribute_map': {
                    'blockchain': 'blockchain',
                    'network': 'network',
                    'context': 'context',
                    'limit': 'limit',
                    'offset': 'offset',
                },
                'location_map': {
                    'blockchain': 'path',
                    'network': 'path',
                    'context': 'query',
                    'limit': 'query',
                    'offset': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def activate_blockchain_event_subscription(
        self,
        reference_id,
        **kwargs
    ):
        """Activate Blockchain Event Subscription  # noqa: E501

        Through this endpoint customers can reactivate an event subscription (callback) which has been deactivated by the system. Deactivations could happen due to various reasons, most often \"maximum retry attempts reached\".  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.activate_blockchain_event_subscription(reference_id, async_req=True)
        >>> result = thread.get()

        Args:
            reference_id (str): Represents a unique ID used to reference the specific callback subscription.

        Keyword Args:
            context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
            activate_blockchain_event_subscription_rb (ActivateBlockchainEventSubscriptionRB): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ActivateBlockchainEventSubscriptionR
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['reference_id'] = \
            reference_id
        return self.activate_blockchain_event_subscription_endpoint.call_with_http_info(**kwargs)

    def delete_blockchain_event_subscription(
        self,
        blockchain,
        network,
        reference_id,
        **kwargs
    ):
        """Delete Blockchain Event Subscription  # noqa: E501

        Through this endpoint the customer can delete blockchain event subscriptions they have by attributes `referenceId` and `network`.    Currently Crypto APIs 2.0 offers certain Blockchain event endpoints which allow the user to subscribe for one/a few/all and receive callback notifications when the specific event occurs.    {note}To have an operational callback subscription, you need to first verify a domain for the Callback URL. Please see more information on Callbacks [here](https://developers.cryptoapis.io/technical-documentation/general-information/callbacks#callback-url).{/note}    {warning}Crypto APIs will notify the user **only when** the event occurs. There are cases when the specific event doesn't happen at all, or takes a long time to do so. A callback notification **will not** be sent if the event does not or cannot occur, or will take long time to occur.{/warning}  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_blockchain_event_subscription(blockchain, network, reference_id, async_req=True)
        >>> result = thread.get()

        Args:
            blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.
            network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\" are test networks.
            reference_id (str): Represents a unique ID used to reference the specific callback subscription.

        Keyword Args:
            context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DeleteBlockchainEventSubscriptionR
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['blockchain'] = \
            blockchain
        kwargs['network'] = \
            network
        kwargs['reference_id'] = \
            reference_id
        return self.delete_blockchain_event_subscription_endpoint.call_with_http_info(**kwargs)

    def get_blockchain_event_subscription_details_by_reference_id(
        self,
        reference_id,
        **kwargs
    ):
        """Get Blockchain Event Subscription Details By Reference ID  # noqa: E501

        Through this endpoint the customer can get detailed information for a callback subscription by providing its reference ID.    Currently Crypto APIs 2.0 offers certain Blockchain event endpoints which allow the user to subscribe for one/a few/all and receive callback notifications when the specific event occurs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_blockchain_event_subscription_details_by_reference_id(reference_id, async_req=True)
        >>> result = thread.get()

        Args:
            reference_id (str): Represents a unique ID used to reference the specific callback subscription.

        Keyword Args:
            context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GetBlockchainEventSubscriptionDetailsByReferenceIDR
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['reference_id'] = \
            reference_id
        return self.get_blockchain_event_subscription_details_by_reference_id_endpoint.call_with_http_info(**kwargs)

    def list_blockchain_events_subscriptions(
        self,
        blockchain,
        network,
        **kwargs
    ):
        """List Blockchain Events Subscriptions  # noqa: E501

        Through this endpoint the customer can obtain a list of their callback subscriptions for the available Blockchain events.    Currently Crypto APIs 2.0 offers certain Blockchain event endpoints which allow the user to subscribe for one/a few/all and receive callback notifications when the specific event occurs.    {note}To have an operational callback subscription, you need to first verify a domain for the Callback URL. Please see more information on Callbacks [here](https://developers.cryptoapis.io/technical-documentation/general-information/callbacks#callback-url).{/note}  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_blockchain_events_subscriptions(blockchain, network, async_req=True)
        >>> result = thread.get()

        Args:
            blockchain (str): Represents the specific blockchain protocol name, e.g. Ethereum, Bitcoin, etc.
            network (str): Represents the name of the blockchain network used; blockchain networks are usually identical as technology and software, but they differ in data, e.g. - \"mainnet\" is the live network with actual data while networks like \"testnet\", \"ropsten\" are test networks.

        Keyword Args:
            context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
            limit (int): Defines how many items should be returned in the response per page basis.. [optional] if omitted the server will use the default value of 50
            offset (int): The starting index of the response items, i.e. where the response should start listing the returned items.. [optional] if omitted the server will use the default value of 0
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ListBlockchainEventsSubscriptionsR
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['blockchain'] = \
            blockchain
        kwargs['network'] = \
            network
        return self.list_blockchain_events_subscriptions_endpoint.call_with_http_info(**kwargs)




"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.create_fungible_tokens_transaction_request_from_address_e401 import CreateFungibleTokensTransactionRequestFromAddressE401
globals()['CreateFungibleTokensTransactionRequestFromAddressE401'] = CreateFungibleTokensTransactionRequestFromAddressE401
from cryptoapis.model.create_fungible_tokens_transaction_request_from_address401_response import CreateFungibleTokensTransactionRequestFromAddress401Response


class TestCreateFungibleTokensTransactionRequestFromAddress401Response(unittest.TestCase):
    """CreateFungibleTokensTransactionRequestFromAddress401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateFungibleTokensTransactionRequestFromAddress401Response(self):
        """Test CreateFungibleTokensTransactionRequestFromAddress401Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateFungibleTokensTransactionRequestFromAddress401Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
from cryptoapis.model.list_transactions_by_block_height_ribsb import ListTransactionsByBlockHeightRIBSB
from cryptoapis.model.list_transactions_by_block_height_ribsbc import ListTransactionsByBlockHeightRIBSBC
from cryptoapis.model.list_transactions_by_block_height_ribsbsc import ListTransactionsByBlockHeightRIBSBSC
from cryptoapis.model.list_transactions_by_block_height_ribsbsc_gas_price import ListTransactionsByBlockHeightRIBSBSCGasPrice
from cryptoapis.model.list_transactions_by_block_height_ribsd import ListTransactionsByBlockHeightRIBSD
from cryptoapis.model.list_transactions_by_block_height_ribsd2 import ListTransactionsByBlockHeightRIBSD2
from cryptoapis.model.list_transactions_by_block_height_ribse import ListTransactionsByBlockHeightRIBSE
from cryptoapis.model.list_transactions_by_block_height_ribsec import ListTransactionsByBlockHeightRIBSEC
from cryptoapis.model.list_transactions_by_block_height_ribsl import ListTransactionsByBlockHeightRIBSL
from cryptoapis.model.list_transactions_by_block_height_ribsz import ListTransactionsByBlockHeightRIBSZ
from cryptoapis.model.list_transactions_by_block_height_ribsz_vin_inner import ListTransactionsByBlockHeightRIBSZVinInner
from cryptoapis.model.list_transactions_by_block_height_ribsz_vout_inner import ListTransactionsByBlockHeightRIBSZVoutInner
from cryptoapis.model.list_transactions_by_block_height_ribszv_join_split_inner import ListTransactionsByBlockHeightRIBSZVJoinSplitInner
from cryptoapis.model.list_transactions_by_block_height_ribszv_shielded_output_inner import ListTransactionsByBlockHeightRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['ListTransactionsByBlockHeightRIBSB'] = ListTransactionsByBlockHeightRIBSB
globals()['ListTransactionsByBlockHeightRIBSBC'] = ListTransactionsByBlockHeightRIBSBC
globals()['ListTransactionsByBlockHeightRIBSBSC'] = ListTransactionsByBlockHeightRIBSBSC
globals()['ListTransactionsByBlockHeightRIBSBSCGasPrice'] = ListTransactionsByBlockHeightRIBSBSCGasPrice
globals()['ListTransactionsByBlockHeightRIBSD'] = ListTransactionsByBlockHeightRIBSD
globals()['ListTransactionsByBlockHeightRIBSD2'] = ListTransactionsByBlockHeightRIBSD2
globals()['ListTransactionsByBlockHeightRIBSE'] = ListTransactionsByBlockHeightRIBSE
globals()['ListTransactionsByBlockHeightRIBSEC'] = ListTransactionsByBlockHeightRIBSEC
globals()['ListTransactionsByBlockHeightRIBSL'] = ListTransactionsByBlockHeightRIBSL
globals()['ListTransactionsByBlockHeightRIBSZ'] = ListTransactionsByBlockHeightRIBSZ
globals()['ListTransactionsByBlockHeightRIBSZVJoinSplitInner'] = ListTransactionsByBlockHeightRIBSZVJoinSplitInner
globals()['ListTransactionsByBlockHeightRIBSZVShieldedOutputInner'] = ListTransactionsByBlockHeightRIBSZVShieldedOutputInner
globals()['ListTransactionsByBlockHeightRIBSZVinInner'] = ListTransactionsByBlockHeightRIBSZVinInner
globals()['ListTransactionsByBlockHeightRIBSZVoutInner'] = ListTransactionsByBlockHeightRIBSZVoutInner
from cryptoapis.model.list_transactions_by_block_height_ribs import ListTransactionsByBlockHeightRIBS


class TestListTransactionsByBlockHeightRIBS(unittest.TestCase):
    """ListTransactionsByBlockHeightRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListTransactionsByBlockHeightRIBS(self):
        """Test ListTransactionsByBlockHeightRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListTransactionsByBlockHeightRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_zilliqa_transaction_details_by_transaction_idri_fee import GetZilliqaTransactionDetailsByTransactionIDRIFee
from cryptoapis.model.get_zilliqa_transaction_details_by_transaction_idri_recipients_inner import GetZilliqaTransactionDetailsByTransactionIDRIRecipientsInner
from cryptoapis.model.get_zilliqa_transaction_details_by_transaction_idri_senders_inner import GetZilliqaTransactionDetailsByTransactionIDRISendersInner
globals()['GetZilliqaTransactionDetailsByTransactionIDRIFee'] = GetZilliqaTransactionDetailsByTransactionIDRIFee
globals()['GetZilliqaTransactionDetailsByTransactionIDRIRecipientsInner'] = GetZilliqaTransactionDetailsByTransactionIDRIRecipientsInner
globals()['GetZilliqaTransactionDetailsByTransactionIDRISendersInner'] = GetZilliqaTransactionDetailsByTransactionIDRISendersInner
from cryptoapis.model.get_zilliqa_transaction_details_by_transaction_idri import GetZilliqaTransactionDetailsByTransactionIDRI


class TestGetZilliqaTransactionDetailsByTransactionIDRI(unittest.TestCase):
    """GetZilliqaTransactionDetailsByTransactionIDRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetZilliqaTransactionDetailsByTransactionIDRI(self):
        """Test GetZilliqaTransactionDetailsByTransactionIDRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetZilliqaTransactionDetailsByTransactionIDRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vin_inner import GetTransactionDetailsByTransactionIDRIBSZVinInner
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vout_inner import GetTransactionDetailsByTransactionIDRIBSZVoutInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_output_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
from cryptoapis.model.list_all_unconfirmed_transactions_ribsb import ListAllUnconfirmedTransactionsRIBSB
from cryptoapis.model.list_all_unconfirmed_transactions_ribsbc import ListAllUnconfirmedTransactionsRIBSBC
from cryptoapis.model.list_all_unconfirmed_transactions_ribsbsc import ListAllUnconfirmedTransactionsRIBSBSC
from cryptoapis.model.list_all_unconfirmed_transactions_ribsd import ListAllUnconfirmedTransactionsRIBSD
from cryptoapis.model.list_all_unconfirmed_transactions_ribsd2 import ListAllUnconfirmedTransactionsRIBSD2
from cryptoapis.model.list_all_unconfirmed_transactions_ribse import ListAllUnconfirmedTransactionsRIBSE
from cryptoapis.model.list_all_unconfirmed_transactions_ribsec import ListAllUnconfirmedTransactionsRIBSEC
from cryptoapis.model.list_all_unconfirmed_transactions_ribsec_fee import ListAllUnconfirmedTransactionsRIBSECFee
from cryptoapis.model.list_all_unconfirmed_transactions_ribsl import ListAllUnconfirmedTransactionsRIBSL
from cryptoapis.model.list_all_unconfirmed_transactions_ribsz import ListAllUnconfirmedTransactionsRIBSZ
from cryptoapis.model.list_confirmed_transactions_by_address_ribsbsc_gas_price import ListConfirmedTransactionsByAddressRIBSBSCGasPrice
from cryptoapis.model.list_confirmed_transactions_by_address_ribszv_join_split_inner import ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVinInner'] = GetTransactionDetailsByTransactionIDRIBSZVinInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVoutInner'] = GetTransactionDetailsByTransactionIDRIBSZVoutInner
globals()['ListAllUnconfirmedTransactionsRIBSB'] = ListAllUnconfirmedTransactionsRIBSB
globals()['ListAllUnconfirmedTransactionsRIBSBC'] = ListAllUnconfirmedTransactionsRIBSBC
globals()['ListAllUnconfirmedTransactionsRIBSBSC'] = ListAllUnconfirmedTransactionsRIBSBSC
globals()['ListAllUnconfirmedTransactionsRIBSD'] = ListAllUnconfirmedTransactionsRIBSD
globals()['ListAllUnconfirmedTransactionsRIBSD2'] = ListAllUnconfirmedTransactionsRIBSD2
globals()['ListAllUnconfirmedTransactionsRIBSE'] = ListAllUnconfirmedTransactionsRIBSE
globals()['ListAllUnconfirmedTransactionsRIBSEC'] = ListAllUnconfirmedTransactionsRIBSEC
globals()['ListAllUnconfirmedTransactionsRIBSECFee'] = ListAllUnconfirmedTransactionsRIBSECFee
globals()['ListAllUnconfirmedTransactionsRIBSL'] = ListAllUnconfirmedTransactionsRIBSL
globals()['ListAllUnconfirmedTransactionsRIBSZ'] = ListAllUnconfirmedTransactionsRIBSZ
globals()['ListConfirmedTransactionsByAddressRIBSBSCGasPrice'] = ListConfirmedTransactionsByAddressRIBSBSCGasPrice
globals()['ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner'] = ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner
from cryptoapis.model.list_all_unconfirmed_transactions_ribs import ListAllUnconfirmedTransactionsRIBS


class TestListAllUnconfirmedTransactionsRIBS(unittest.TestCase):
    """ListAllUnconfirmedTransactionsRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListAllUnconfirmedTransactionsRIBS(self):
        """Test ListAllUnconfirmedTransactionsRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListAllUnconfirmedTransactionsRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_hd_wallet_x_pub_y_pub_z_pub_assets_e401 import GetHDWalletXPubYPubZPubAssetsE401
globals()['GetHDWalletXPubYPubZPubAssetsE401'] = GetHDWalletXPubYPubZPubAssetsE401
from cryptoapis.model.get_hd_wallet_x_pub_y_pub_z_pub_assets401_response import GetHDWalletXPubYPubZPubAssets401Response


class TestGetHDWalletXPubYPubZPubAssets401Response(unittest.TestCase):
    """GetHDWalletXPubYPubZPubAssets401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetHDWalletXPubYPubZPubAssets401Response(self):
        """Test GetHDWalletXPubYPubZPubAssets401Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetHDWalletXPubYPubZPubAssets401Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.banned_ip_address_details_inner import BannedIpAddressDetailsInner
from cryptoapis.model.could_not_calculate_rate_for_pair import CouldNotCalculateRateForPair
from cryptoapis.model.invalid_request_body_structure import InvalidRequestBodyStructure
globals()['BannedIpAddressDetailsInner'] = BannedIpAddressDetailsInner
globals()['CouldNotCalculateRateForPair'] = CouldNotCalculateRateForPair
globals()['InvalidRequestBodyStructure'] = InvalidRequestBodyStructure
from cryptoapis.model.get_exchange_rate_by_asset_symbols_e422 import GetExchangeRateByAssetSymbolsE422


class TestGetExchangeRateByAssetSymbolsE422(unittest.TestCase):
    """GetExchangeRateByAssetSymbolsE422 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetExchangeRateByAssetSymbolsE422(self):
        """Test GetExchangeRateByAssetSymbolsE422"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetExchangeRateByAssetSymbolsE422()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.banned_ip_address_details_inner import BannedIpAddressDetailsInner
from cryptoapis.model.invalid_pagination import InvalidPagination
from cryptoapis.model.limit_greater_than_allowed import LimitGreaterThanAllowed
from cryptoapis.model.uri_not_found import UriNotFound
globals()['BannedIpAddressDetailsInner'] = BannedIpAddressDetailsInner
globals()['InvalidPagination'] = InvalidPagination
globals()['LimitGreaterThanAllowed'] = LimitGreaterThanAllowed
globals()['UriNotFound'] = UriNotFound
from cryptoapis.model.new_confirmed_tokens_transactions_and_each_confirmation_e400 import NewConfirmedTokensTransactionsAndEachConfirmationE400


class TestNewConfirmedTokensTransactionsAndEachConfirmationE400(unittest.TestCase):
    """NewConfirmedTokensTransactionsAndEachConfirmationE400 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNewConfirmedTokensTransactionsAndEachConfirmationE400(self):
        """Test NewConfirmedTokensTransactionsAndEachConfirmationE400"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NewConfirmedTokensTransactionsAndEachConfirmationE400()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_internal_transactions_by_address_and_time_range_e403 import ListInternalTransactionsByAddressAndTimeRangeE403
globals()['ListInternalTransactionsByAddressAndTimeRangeE403'] = ListInternalTransactionsByAddressAndTimeRangeE403
from cryptoapis.model.list_internal_transactions_by_address_and_time_range403_response import ListInternalTransactionsByAddressAndTimeRange403Response


class TestListInternalTransactionsByAddressAndTimeRange403Response(unittest.TestCase):
    """ListInternalTransactionsByAddressAndTimeRange403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListInternalTransactionsByAddressAndTimeRange403Response(self):
        """Test ListInternalTransactionsByAddressAndTimeRange403Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListInternalTransactionsByAddressAndTimeRange403Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.banned_ip_address_details_inner import BannedIpAddressDetailsInner
from cryptoapis.model.invalid_request_body_structure import InvalidRequestBodyStructure
from cryptoapis.model.xpub_sync_in_progress import XpubSyncInProgress
globals()['BannedIpAddressDetailsInner'] = BannedIpAddressDetailsInner
globals()['InvalidRequestBodyStructure'] = InvalidRequestBodyStructure
globals()['XpubSyncInProgress'] = XpubSyncInProgress
from cryptoapis.model.sync_hd_wallet_x_pub_y_pub_z_pub_e422 import SyncHDWalletXPubYPubZPubE422


class TestSyncHDWalletXPubYPubZPubE422(unittest.TestCase):
    """SyncHDWalletXPubYPubZPubE422 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSyncHDWalletXPubYPubZPubE422(self):
        """Test SyncHDWalletXPubYPubZPubE422"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SyncHDWalletXPubYPubZPubE422()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
